import unittest
import json
from TradeGates.TradeGate import TradeGate
import logging


class BinanceMarketInfoTest(unittest.TestCase):
    def setUp(self):
        with open('./config.json') as f:
            config = json.load(f)

        self.tradeGate = TradeGate(config['Binance'], sandbox=False)
        loglevel = logging.INFO
        logging.basicConfig(level=loglevel)
        self.log = logging.getLogger(__name__)

    @unittest.skip
    def testTradingFees(self):
        # self.log.info('\nTrading Fees: {}'.format(self.tradeGate.getTradingFees()))
        self.assertIsNotNone(self.tradeGate.getTradingFees(), 'Problem in fetching trading fees.')

    def testAveragePrice(self):
        # self.log.info('\BTCUSDT Average Price: {}'.format(self.tradeGate.getSymbolAveragePrice('BTCUSDT')))
        self.assertIsNotNone(self.tradeGate.getSymbolAveragePrice('BTCUSDT'), 'Problem in fetching symbol average price.')

    def testLatestTrades(self):
        # self.log.info('\nLatest Trades For BTCUSDT: {}'.format(self.tradeGate.getSymbolLatestTrades('BTCUSDT')))
        self.assertIsNotNone(self.tradeGate.getSymbolLatestTrades('BTCUSDT'), 'Problem in fetching latest trades.')

    def testTickerPrice(self):
        # self.log.info('\n"BTCUSDT" Ticker Price: {}'.format(self.tradeGate.getSymbolTickerPrice('BTCUSDT')))
        self.assertIsNotNone(self.tradeGate.getSymbolTickerPrice('BTCUSDT'), 'Problem in fetching symbol\'s ticker price')
    
    def testKlines(self):
        # self.log.info('\n"BTCUSDT" Ticker Price: {}'.format(self.tradeGate.getSymbolKlines('BTCUSDT', '1m', limit=10)))
        data = self.tradeGate.getSymbolKlines('BTCUSDT', '15m', limit=10, futures=True, doClean=True, convertDateTime=True)
        # self.log.info('\n')
        # for candle in data:
        #     self.log.info(candle)
        # self.log.info('\n')
        self.assertIsNotNone(data, 'Problem in fetching spot market candle data.')
        self.assertIsNotNone(data)
        self.assertEqual(len(data), 10, 'Length of spot market candle data is incorrect.')
        self.assertIsNotNone(self.tradeGate.getSymbolKlines('BTCUSDT', '15m', limit=10, futures=True), 'Problem in fetching futures candle data.')

        data = self.tradeGate.getSymbolKlines('BTCUSDT', '15m', limit=10, futures=True, toCleanDataframe=True)
        assert data.shape == (10, 7), '7 columns were excpected, but failed'

    def testExchangeTime(self):
        self.assertIsNotNone(self.tradeGate.getExchangeTime(), 'Problem in fetching exchange time. Probably connectivity issues.')


if __name__ == '__main__':
    unittest.main()


import setuptools
import os
import sys
import shutil

with open("README.md", "r") as fh:
    long_description = fh.read()

try:
    shutil.rmtree('./build')
    shutil.rmtree('./dist')
except OSError as e:
    print ("Error: %s - %s." % (e.filename, e.strerror))


setuptools.setup(
    name="TradeGate",                     # This is the name of the package
    version="0.0.9",
    author="Rustin Soraki",                     # Full name of the author
    description="A Trading Gateway",
    long_description=long_description,      # Long description read from the the readme file
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(where='TradeGates'),    # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                      # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    py_modules=["TradeGate"],             # Name of the python package
    package_dir={'':'TradeGates'},     # Directory of the source code of the package
    install_requires=['binance-connector', 'requests', 'apscheduler', 'websocket-client', 'urllib3', 'tzlocal<3.0', 'pandas']                     # Install other dependencies if any
)

# python setup.py sdist bdist_wheel  
# twine check dist/*   
# twine upload dist/*  